from setuptools import setup

setup(
    name="abram_text_library",
    version="1.0.0",
    description="A library made by a 10-year-old to print text in cool ways",
    author="Abram Jindal",
    py_modules=["text"],
    install_requires=["rich"],
)